/*
     This file is part of GNUnet.
     (C) 2001, 2002, 2003 Christian Grothoff (and other contributing authors)

     GNUnet is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2, or (at your
     option) any later version.

     GNUnet is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with GNUnet; see the file COPYING.  If not, write to the
     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
*/

/**
 * @file applications/afs/tools/gnunet-pseudonym-create.c
 * @brief create a new pseudoynm
 * @author Christian Grothoff
 **/

#include "gnunet_afs_esed2.h"

static char * pname = NULL;
      
static void printhelp() {
  printf("USAGE: gnunet-pseudonym-create [OPTIONS] PSEUDONYM\n"\
         "-p PASS, --password=PASS      : "
	 "password for this pseudonym\n");
  printHelpDefault();
}

/**
 * Perform option parsing from the command line. 
 **/
static int parser(int argc, 
 	   char * argv[]) {
  int cont = OK;
  int c;

  while (1) {
    int option_index = 0;
    static struct GNoption long_options[] = {
      LONG_DEFAULT_OPTIONS,
      { "password", 1, 0, 'p' },
      { 0,0,0,0 }
    };
    
    c = GNgetopt_long(argc,
		      argv, 
		      "vhc:L:p:", 
		      long_options, 
		      &option_index);
    
    if (c == -1) 
      break;  /* No more flags to process */
    if (YES == parseDefaultOptions(c, GNoptarg))
      continue;
    switch(c) {
    case 'p':
      FREENONNULL(setConfigurationString("PSEUDONYM",
					 "PASSWORD",
					 GNoptarg));
      break;
    case 'v': 
      printf("gnunet-pseudoynm-create v%s\n",
	     VERSION);
      cont = SYSERR;
      break;
    case 'h': 
      printhelp();
      cont = SYSERR;
      break;
    default:
      LOG(LOG_FAILURE, 
	  "FAILURE: Unknown option %c. Aborting.\n"\
	  "Use --help to get a list of options.\n",
	  c);
      cont = SYSERR;    
    } /* end of parsing commandline */
  }
  if (GNoptind < argc)
    pname = argv[GNoptind++];
  if (GNoptind < argc) {
    LOG(LOG_WARNING, 
	"WARNING: Invalid arguments: ");
    while (GNoptind < argc)
      LOG(LOG_WARNING, 
	  "%s ", argv[GNoptind++]);
    LOG(LOG_FATAL,
	"FATAL: Invalid arguments. Exiting.\n");
    return SYSERR;
  }
  return cont;
}


int main(int argc, char *argv[]) {
  char * password;
  HOSTKEY hk;
  
  if (OK != initUtil(argc, argv, &parser))
    return SYSERR;
  if (pname == NULL) {
    printf("You must specify a name for the pseudonym.\n");
    doneUtil();
    return SYSERR;    
  }
  password = getConfigurationString("PSEUDONYM",
				    "PASSWORD");
  if(password == NULL || password[0]=='\n')
    LOG(LOG_WARNING, "WARNING: No password supplied\n");

  hk = createPseudonym(pname,
		       password);
  if (hk == NULL) {
    printf("Could not create pseudonym %s (exists?).\n",
	   pname);
  } else {
    printf("Pseudonym %s created.\n",
	   pname);
    freeHostkey(hk);
  } 


  FREENONNULL(password);
  doneUtil();
  return 0;
}


/* end of gnunet-pseudonym-create.c */
